Module checks

Module checks 

Contains definitions for cradle checks

Structs

CheckResult
Check result struct Each cradle check should return this struct after execution

Enums

Severity
Check result severity Specifies how severe the check result should be classified as