pub struct CheckResult {
pub plugin: String,
pub check: String,
pub severity: Severity,
pub message: String,
pub details: Option<String>,
}Expand description
Check result struct Each cradle check should return this struct after execution
Fields
plugin: StringCalling plugin name
check: StringCheck name
severity: SeverityResult severity (see: Severity)
message: StringMessage included in the check’s result
details: Option<String>Optional details for the message
Implementations
Sourceimpl CheckResult
impl CheckResult
Sourcepub fn pass(plugin: &str, check: &str, message: impl Into<String>) -> Self
pub fn pass(plugin: &str, check: &str, message: impl Into<String>) -> Self
Small helper to create a pass result (Severity::Pass)
Sourcepub fn info(plugin: &str, check: &str, message: impl Into<String>) -> Self
pub fn info(plugin: &str, check: &str, message: impl Into<String>) -> Self
Small helper to create an informational result (Severity::Info)
Sourcepub fn warn(plugin: &str, check: &str, message: impl Into<String>) -> Self
pub fn warn(plugin: &str, check: &str, message: impl Into<String>) -> Self
Small helper to create a warning result (Severity::Warn)
Sourcepub fn fail(plugin: &str, check: &str, message: impl Into<String>) -> Self
pub fn fail(plugin: &str, check: &str, message: impl Into<String>) -> Self
Small helper to create a failure result (Severity::Fail)
Sourcepub fn critical(plugin: &str, check: &str, message: impl Into<String>) -> Self
pub fn critical(plugin: &str, check: &str, message: impl Into<String>) -> Self
Small helper to create a critical error result (Severity::Critical)
Sourcepub fn with_details(self, details: impl Into<String>) -> Self
pub fn with_details(self, details: impl Into<String>) -> Self
Adds details to the given check result