Module consts

Module consts 

Constants shared by the agent and CLI

Constants

CMD_RUN
Run command Sent by the cli Tells the agent to start the checks
CMD_STATUS
Status command Sent by the cli Requests the agent’s current status
CMD_STOP
Stop command Sent by the cli Tells the agent to stop executing
RESP_DONE
Done response Sent by the agent Tells the cli that the agent has finished its execution
RESP_ERROR
Error response Sent by the agent Tells the cli that an error has occurred during agent execution
RESP_LOG
Log response Sent by the agent Tells the cli that the following message contains an agent log entry
RESP_RESULT
Result response Sent by the agent Tells the cli that the following message contains a check result
SHARED_VERSION
Constant that contains this crate’s package version