Constants shared by the agent and CLI
Constants
- CMD_RUN
- Run command Sent by the cli Tells the agent to start the checks
- CMD_
STATUS - Status command Sent by the cli Requests the agent’s current status
- CMD_
STOP - Stop command Sent by the cli Tells the agent to stop executing
- RESP_
DONE - Done response Sent by the agent Tells the cli that the agent has finished its execution
- RESP_
ERROR - Error response Sent by the agent Tells the cli that an error has occurred during agent execution
- RESP_
LOG - Log response Sent by the agent Tells the cli that the following message contains an agent log entry
- RESP_
RESULT - Result response Sent by the agent Tells the cli that the following message contains a check result
- SHARED_
VERSION - Constant that contains this crate’s package version